Function uber_api::pod_retrieval

source ·
pub async fn pod_retrieval(
    access_token: &str,
    customer_id: &str,
    delivery_id: &str,
    pod_retrieval_request: PODRetrievalRequest
) -> Result<(PODRetrievalResponse, String), UberError>
Return a Proof-of-Delivery (P.O.D.) File if verification requirement given in create delivery request

If a delivery is created with any verification requirements (e.g.: picture, signature or pincode), the resulting image file is made available to you through our proof-of-delivery endpoint. The endpoint will return a Proof-of-Delivery (P.O.D.) File – A long Base64 string that can be converted to a PNG image (Web Converter (External)). The image will include the following information:

  • Delivery Status

  • Delivery timestamp

  • Uber Order ID

  • External Order ID

  • Proof Type

  • Image (Signature image, picture image, or pincode value)

For the “signature” verification type, signer name or signer relationship will also be included if it is enabled for a delivery.

Request Body Parameters -

NameTypeDescription
waypointstringWaypoint can be “pickup” or “dropoff” or “return”.
typestringType can be “picture” or “signature” or “pincode”.

Response Body Parameters

|Name |Type| Description| | :— | :— | |document| string| A long Base64 string representing the image.|

Endpoint Specific Errors

Http Status CodeCodeMessage
404delivery_not_foundCannot find requested proof of delivery.
400invalid_paramsWaypoint, type is invalid.
404customer_not_coundCustomer does not exist.
500unknown_errorAn unknown error happened.