Function uber_api::pod_retrieval
source · pub async fn pod_retrieval(
access_token: &str,
customer_id: &str,
delivery_id: &str,
pod_retrieval_request: PODRetrievalRequest
) -> Result<(PODRetrievalResponse, String), UberError>Expand description
Return a Proof-of-Delivery (P.O.D.) File if verification requirement given in create delivery request
If a delivery is created with any verification requirements (e.g.: picture, signature or pincode), the resulting image file is made available to you through our proof-of-delivery endpoint. The endpoint will return a Proof-of-Delivery (P.O.D.) File – A long Base64 string that can be converted to a PNG image (Web Converter (External)). The image will include the following information:
-
Delivery Status
-
Delivery timestamp
-
Uber Order ID
-
External Order ID
-
Proof Type
-
Image (Signature image, picture image, or pincode value)
For the “signature” verification type, signer name or signer relationship will also be included if it is enabled for a delivery.
Request Body Parameters -
| Name | Type | Description |
|---|---|---|
| waypoint | string | Waypoint can be “pickup” or “dropoff” or “return”. |
| type | string | Type can be “picture” or “signature” or “pincode”. |
Response Body Parameters
|Name |Type| Description| | :— | :— | |document| string| A long Base64 string representing the image.|
Endpoint Specific Errors
| Http Status Code | Code | Message |
|---|---|---|
| 404 | delivery_not_found | Cannot find requested proof of delivery. |
| 400 | invalid_params | Waypoint, type is invalid. |
| 404 | customer_not_cound | Customer does not exist. |
| 500 | unknown_error | An unknown error happened. |